@@ -27,7 +27,7 @@ import hicstuff.iteralign as hci
 import metator.network as mtn
 from metator.log import logger
 from os.path import join
-from pkg_resources import parse_version
+from looseversion import LooseVersion
 
 
 def align(
@@ -88,8 +88,8 @@ def align(
         )
         st.rmtree(iter_tmp_dir)
         sp.call(
-            "samtools sort -F 2048 -n -@ {n_cpu} -o {out} {tmp}".format(
-                n_cpu=n_cpu, tmp=tmp_bam, out=bam_out
+            "samtools sort -n -@ {n_cpu} -o {bam} {tmp}".format(
+                n_cpu=n_cpu, tmp=tmp_bam, bam=bam_out
             ),
             shell=True,
         )
@@ -113,14 +113,16 @@ def align(
             ).format(**map_args)
 
         # Write the outputfile in a temporary bam file.
-        map_process = sp.Popen(cmd, shell=True, stdout=sp.PIPE)
+        map_process = sp.Popen(cmd, shell=True, stdout=sp.PIPE, stderr=sp.PIPE)
         sort_process = sp.Popen(
             "samtools sort -n -@ {cpus} -o {bam}".format(**map_args),
             shell=True,
             stdin=map_process.stdout,
         )
         _out, _err = sort_process.communicate()
-
+        mapping_values = map_process.stderr.read()
+        for line in mapping_values.split(b"\n"):
+            logger.info(f"{line.decode('utf-8')}")
     return 0
 
 
@@ -235,7 +237,7 @@ def get_contact_pairs(
                     enzyme=enzyme,
                     mode="for_vs_rev",
                     seed_size=20,
-                    n_cpu=n_cpu,
+                    n_cpu=int(n_cpu),
                 )
                 for_in, rev_in = digest_for, digest_rev
 
@@ -248,11 +250,11 @@ def get_contact_pairs(
                 alignment_rev = join(out_dir, name + "_rev.bam")
 
                 # Align the forward reads
-                logger.info("Alignment of %s:", for_in)
+                logger.info(f"Alignment of {for_in}:")
                 align(for_in, index, aligner, alignment_for, n_cpu, iterative)
 
                 # Align the reverse reads
-                logger.info("Alignment of %s:", rev_in)
+                logger.info(f"Alignment of  {rev_in}:")
                 align(
                     rev_in,
                     index,
@@ -265,7 +267,7 @@ def get_contact_pairs(
             elif aligner == "bwa":
                 # Create file to save the alignement.
                 alignment = join(out_dir, name + ".bam")
-                logger.info("Alignment of %s and %s:", for_in, rev_in)
+                logger.info(f"Alignment of {for_in} and {rev_in}:")
                 align(
                     for_in,
                     index,
@@ -278,7 +280,7 @@ def get_contact_pairs(
 
         elif start == "bam":
             if aligner == "bowtie2":
-                logger.info("Processing %s and %s:", for_in, rev_in)
+                logger.info(f"Processing {for_in} and {rev_in}:")
                 alignment_for = for_in
                 alignment_rev = rev_in
             elif aligner == "bwa":
@@ -302,9 +304,7 @@ def get_contact_pairs(
                 alignment_rev, min_qual, alignment_temp_rev
             )
             logger.info(
-                "%s forward reads aligned and %s reverse reads aligned",
-                aligned_reads_for,
-                aligned_reads_rev,
+                f"{aligned_reads_for} forward reads aligned and {aligned_reads_rev} reverse reads aligned."
             )
 
             # Merge alignement to create a pairs file
@@ -312,7 +312,7 @@ def get_contact_pairs(
             n_pairs = merge_alignment(
                 alignment_temp_for, alignment_temp_rev, contig_data, out_file
             )
-            logger.info("%s pairs aligned.", n_pairs)
+            logger.info(f"{n_pairs} pairs aligned.\n")
             total_aligned_pairs += n_pairs
 
         # Case where a bam file from bwa is given as input.
@@ -320,11 +320,11 @@ def get_contact_pairs(
             n_pairs = process_bwa_bamfile(
                 alignment, min_qual, contig_data, out_file
             )
-            logger.info("%s pairs aligned.", n_pairs)
+            logger.info(f"{n_pairs} pairs aligned.\n")
             total_aligned_pairs += n_pairs
 
     if len(out_file_list) > 1:
-        logger.info("TOTAL PAIRS MAPPED: %s", total_aligned_pairs)
+        logger.info(f"TOTAL PAIRS MAPPED: {total_aligned_pairs}\n")
 
     return out_file_list, contig_data, hit_data
 
@@ -439,7 +439,7 @@ def merge_alignment(forward_aligned, reverse_aligned, contig_data, out_file):
             # according to the version order.
             else:
                 names = [for_read[0], rev_read[0]]
-                names_sorted = sorted(names, key=parse_version)
+                names_sorted = sorted(names, key=LooseVersion)
                 # Case of the forward read mapped but not the reverse. Indeed,
                 # no line would have been added previously if the read didn't
                 # map.
@@ -486,7 +486,7 @@ def process_bamfile(alignment, min_qual, filtered_out):
     save = pysam.set_verbosity(0)
     temp_bam = pysam.AlignmentFile(alignment, "rb", check_sq=False)
     pysam.set_verbosity(save)
-    with open(filtered_out, "a") as f:
+    with open(filtered_out, "w") as f:
         for r in temp_bam:
             # Check mapping quality
             if r.mapping_quality >= min_qual:
@@ -594,9 +594,7 @@ def process_bwa_bamfile(alignment, min_qual, contig_data, out_file):
                         # Safety check (forward and reverse are the same reads)
                         if for_read.query_name != rev_read.query_name:
                             logger.error(
-                                "Reads should be paired - %s\t%s",
-                                for_read.query_name,
-                                rev_read.query_name,
+                                f"Reads should be paired - {for_read.query_name}\t{rev_read.query_name}"
                             )
                             raise ValueError
 
